#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cabal-install-parsers
version:              0.4
visibility:           public
id:                   cabal-install-parsers-0.4-F9vzB2aplG9JLCKpi8Xwr8
key:                  cabal-install-parsers-0.4-F9vzB2aplG9JLCKpi8Xwr8
license:              GPL-2.0-or-later AND BSD-3-Clause
maintainer:           hvr@gnu.org, oleg.grenrus@iki.fi
author:               Herbert Valerio Riedel, Oleg Grenrus
homepage:             https://haskell-ci.rtfd.org/
synopsis:             Utilities to work with cabal-install files
description:
    @cabal-install-parsers@ provides parsers for @cabal-install@ files:
    @cabal.project@ ("Cabal.Project"),
    @cabal.config@ ("Cabal.Config"),
    @01-index.tar@ ("Cabal.Index");
    as well as some other utilities.

    The feature set is mainly motivated by the needs of @haskell-ci@ package.
    The parsed data is not complete, functionality is added on demand.

category:             Development
abi:                  769e66631fa5c59137d7b30b10f9e6b1
exposed:              True
exposed-modules:
    Cabal.Config Cabal.Index Cabal.Optimization Cabal.Package
    Cabal.Parse Cabal.Project Cabal.SourceRepo

hidden-modules:       Cabal.Internal.Glob Cabal.Internal.Newtypes
import-dirs:          /usr/lib/ghc-8.10.2/site-local/cabal-install-parsers-0.4
library-dirs:         /usr/lib/ghc-8.10.2/site-local/cabal-install-parsers-0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/cabal-install-parsers-0.4
hs-libraries:         HScabal-install-parsers-0.4-F9vzB2aplG9JLCKpi8Xwr8
depends:
    Cabal-3.2.0.0 aeson-1.5.4.1-DnAbBYGYPRb2Wb6UPOkxl3 base-4.14.1.0
    base16-bytestring-1.0.1.0-PusAkIRpRD5IPv4jfyytk binary-0.8.8.0
    binary-instances-1.0.1-L7YmbYITdsA7bxcPxyKocl bytestring-0.10.10.0
    containers-0.6.2.1
    cryptohash-sha256-0.11.101.0-BuPrA3Ypvec5cIpDYLm0FN deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1
    lukko-0.1.1.2-UnxhsKG2SREOf7a7cKKLG
    network-uri-2.6.3.0-8tJyeRBDup92wNsuQRxrki parsec-3.1.14.0
    pretty-1.1.3.6 tar-0.5.1.1-DkR7zBBUhy89jXo1Rd3LhL text-1.2.3.2
    time-1.9.3 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cabal-install-parsers/html/cabal-install-parsers.haddock

haddock-html:         /usr/share/doc/haskell-cabal-install-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

